pygeodesy.auxilats.auxAngle

Package pygeodesy :: Package auxilats :: Module auxAngle |
[frames] | no frames]

# Module auxAngle

(INTERNAL) Auxiliary latitudes' base classes, constants and functions.

Class AuxAngle transcoded to Python from Karney's C++ class AuxAngle in GeographicLib version 2.2+.

Copyright (C) Charles Karney (2022-2024) and licensed under the MIT/X11 License. For more information, see the GeographicLib documentation.

Version: 25.12.02

Classes
| AuxAngle An accurate representation of angles
| AuxBeta A Parametric, Auxiliary latitude.
| AuxChi A Conformal, Auxiliary latitude.
| AuxMu A Rectifying, Auxiliary latitude.
| AuxPhi A Geodetic or Geographic, Auxiliary latitude.
| AuxTheta A Geocentric, Auxiliary latitude.
| AuxXi An Authalic, Auxiliary latitude.